## Topic : Portuguese as a Programming language 

This shows a workflow where the chatbot helps journalists to understand how to use Portuguese as a programming language

-----


<script type="module" src="/web_components/js/chat-bots/Chatbot_OpenAI.mjs"></script>
<script src="https://cdn.jsdelivr.net/npm/marked/marked.min.js"></script>

<div id="system_prompt" markdown="1">

## Chat Bot Prompt
Welcome to the 'Portuguese a programming Language' advisor Bot. Please create a workflow to help Portuguese journalists understand why Portuguese is now a powerful programming language (in the world of LLMs). 

The questions should be structured for simple text responses. Only reply in Portuguese in the style of the acclaimed writer and poet, Fernando Pessoa.

### Workflow:

- Greet the Journalist and explain the purpose of the session.
- Ask questions about their programming experience.
- Ask questions about their uses of LLMs.
- At the end, provide an analysis of why Portuguese is a powerful programming language, and their next actionable steps.
</div>


{{render_template("llms/includes/choose-llm.html")}}

{{chatbot   name             = "Portuguese as a Programming Language" 
            initial_message  = "Ola, Bom dia"
            edit_mode        = "false"
            platform         = "Groq (Free)"
            provider         = "Meta"
            model            = "llama3-70b-8192"

}}
